@@ -162,6 +162,15 @@
 #' supplied, will override `boot_ci`
 #' and `mc_ci`.
 #'
+#' @param boot_type If bootstrap
+#' confidence interval is to be formed,
+#' the type of bootstrap confidence
+#' interval. The supported types
+#' are `"perc"` (percentile bootstrap
+#' confidence interval, the default and
+#' recommended type) and `"bc"`
+#' (bias-corrected, or BC, bootstrap
+#' confidence interval).
 #'
 #' @param ... Arguments to be passed to
 #' [cond_indirect_effects()]
@@ -234,7 +243,9 @@ index_of_mome <- function(x,
                           mc_out = NULL,
                           ci_type = NULL,
                           ci_out = NULL,
+                          boot_type = c("perc", "bc"),
                           ...) {
+    boot_type <- match.arg(boot_type)
     if (is.null(w) || length(w) != 1) {
         stop("The path must have exactly one moderator.")
       }
@@ -259,6 +270,7 @@ index_of_mome <- function(x,
                                  mc_out = mc_out,
                                  ci_type = ci_type,
                                  ci_out = ci_out,
+                                 boot_type = boot_type,
                                  ...)
     out <- cond_indirect_diff(out, from = 2, to = 1, level = level)
     out$type <- "index_of_mome"
@@ -315,7 +327,9 @@ index_of_momome <- function(x,
                             mc_out = NULL,
                             ci_type = NULL,
                             ci_out = NULL,
+                            boot_type = c("perc", "bc"),
                             ...) {
+    boot_type <- match.arg(boot_type)
     if (is.null(w) || is.null(z) ||
         length(w) != 1 || length(z) != 1) {
         stop("The path must have exactly two moderators.")
@@ -343,6 +357,7 @@ index_of_momome <- function(x,
                                  mc_out = mc_out,
                                  ci_type = ci_type,
                                  ci_out = ci_out,
+                                 boot_type = boot_type,
                                  ...)
     i0 <- cond_indirect_diff(out, from = 4, to = 3, level = level)
     i1 <- cond_indirect_diff(out, from = 2, to = 1, level = level)
@@ -360,40 +375,42 @@ index_of_momome <- function(x,
     if (all(has_mc, has_boot)) stop("Cannot for both Monte Carlo and bootstrap confidence intervals.")
     if (has_mc) {
         ind_mc <- i1$mc_diff - i0$mc_diff
-        tmp <- list(t = matrix(ind_mc, nrow = length(ind_mc), ncol = 1),
-                    t0 = ind,
-                    R = length(ind_mc))
-        mc_ci0 <- boot::boot.ci(tmp, conf = level, type = "perc")
-        ind_mc_ci <- mc_ci0$percent[4:5]
-        names(ind_mc_ci) <- paste0(formatC(c(100 * (1 - level) / 2,
-                                      100 * (1 - (1 - level) / 2)), 2,
-                                      format = "f"), "%")
+        ind_mc_ci <- boot_ci_internal(t0 = ind,
+                                      t = ind_mc,
+                                      level = level,
+                                      boot_type = "perc")
+        ind_mc_se <- stats::sd(ind_mc, na.rm = TRUE)
       } else {
         ind_mc <- NA
         ind_mc_ci <- NA
+        ind_mc_se <- NA
       }
     if (has_boot) {
         ind_boot <- i1$boot_diff - i0$boot_diff
-        tmp <- list(t = matrix(ind_boot, nrow = length(ind_boot), ncol = 1),
-                    t0 = ind,
-                    R = length(ind_boot))
-        boot_ci0 <- boot::boot.ci(tmp, conf = level, type = "perc")
-        ind_boot_ci <- boot_ci0$percent[4:5]
-        names(ind_boot_ci) <- paste0(formatC(c(100 * (1 - level) / 2,
-                                      100 * (1 - (1 - level) / 2)), 2,
-                                      format = "f"), "%")
+        ind_boot_ci <- boot_ci_internal(t0 = ind,
+                               t = ind_boot,
+                               level = level,
+                               boot_type = boot_type)
         ind_boot_p <- est2p(ind_boot)
+        ind_boot_se <- stats::sd(ind_boot, na.rm = TRUE)
       } else {
         ind_boot <- NA
         ind_boot_ci <- NA
         ind_boot_p <- NA
+        ind_boot_se <- NA
       }
     ind_ci <- NA
+    ind_se <- NA
     if (has_mc) ind_ci <- ind_mc_ci
     if (has_boot) ind_ci <- ind_boot_ci
+    if (has_mc) ind_se <- ind_mc_se
+    if (has_boot) ind_se <- ind_boot_se
+    if (has_mc) ci_type <- "mc"
+    if (has_boot) ci_type <- "boot"
     out <- list(index = ind,
                 ci = ind_ci,
                 pvalue = ind_boot_p,
+                se = ind_se,
                 level = level,
                 from = i0$from,
                 to = i0$to,
@@ -402,7 +419,9 @@ index_of_momome <- function(x,
                 output = out,
                 boot_diff = ind_boot,
                 mc_diff = ind_mc,
-                type = "index_of_momome")
+                type = "index_of_momome",
+                boot_type = boot_type,
+                ci_type = ci_type)
     class(out) <- c("cond_indirect_diff", class(out))
     out
   }
